@@ -571,7 +571,17 @@ main (int argc, char *argv[])
 			g_debug ("Scaling thumbnail from %u×%u to %u×%u with for output size %i with scaling factor %f.",
 			         original_width, original_height, scaled_width, scaled_height, output_size, scale);
 
+			if (scaled_width == 0 || scaled_height == 0) {
+				status = STATUS_ERROR_GENERATING_THUMBNAIL;
+				goto done;
+			}
+
+#if HAVE_GDK_PIXBUF_2_36_5
+			scaled_pixbuf = gdk_pixbuf_scale_simple (pixbuf, scaled_width, scaled_height, GDK_INTERP_HYPER);
+#else
 			scaled_pixbuf = gnome_desktop_thumbnail_scale_down_pixbuf (pixbuf, scaled_width, scaled_height);
+#endif
+
 			g_object_unref (pixbuf);
 			pixbuf = scaled_pixbuf;  /* transfer ownership */
 			scaled_pixbuf = NULL;
@@ -586,7 +596,7 @@ main (int argc, char *argv[])
 		gint scaled_overlay_size, scaled_overlay_x, scaled_overlay_y;
 		gdouble scale;
 
-		/* Re-query the dimensions since we don’t know which dimensions gnome_desktop_thumbnail_scale_down_pixbuf() chose. */
+		/* Re-query the dimensions since we don’t know which dimensions gdk_pixbuf_scale_simple() chose. */
 		scaled_width = gdk_pixbuf_get_width (pixbuf);
 		scaled_height = gdk_pixbuf_get_height (pixbuf);
 
